@@ -32,13 +32,22 @@ unsigned char *read_from_disk(u_int64_t offset, f_info *i, u_int64_t length)
 
 	u_int64_t		bytesread = 0;
 	unsigned char	*newbuf = (unsigned char *)malloc(length * sizeof(char));
+	if (!newbuf) {
+           fprintf(stderr, "Ran out of memory in read_from_disk()\n");
+           exit(1);
+         }
 
 	fseeko(i->handle, offset, SEEK_SET);
 	bytesread = fread(newbuf, 1, length, i->handle);
 	if (bytesread != length)
+	{
+		free(newbuf);
 		return NULL;
+	}
 	else
+	{
 		return newbuf;
+	}
 }
 
 /*
@@ -303,6 +312,9 @@ int search_chunk(f_state *s, unsigned char *buf, f_info *i, u_int64_t chunk_size
 {
 
 	u_int64_t		c_offset = 0;
+	//u_int64_t               foundat_off = 0;
+	//u_int64_t               buf_off = 0;
+
 	unsigned char	*foundat = buf;
 	unsigned char	*current_pos = NULL;
 	unsigned char	*header_pos = NULL;
@@ -318,7 +330,7 @@ int search_chunk(f_state *s, unsigned char *buf, f_info *i, u_int64_t chunk_size
 	int				rem = 0;
 	int				x = 0;
 	int				found_ind = FALSE;
-
+	 off_t saveme;
 	//char comment[32];
 	for (j = 0; j < s->num_builtin; j++)
 		{
@@ -338,7 +350,9 @@ int search_chunk(f_state *s, unsigned char *buf, f_info *i, u_int64_t chunk_size
 
 			//if((foundat-buf)< 1 ) break;	
 #ifdef DEBUG
-			printf("current buf:=%llu (foundat-buf)=%d \n", current_buflen, (foundat - buf));
+			//foundat_off=foundat;
+			//buf_off=buf;
+			//printf("current buf:=%llu (foundat-buf)=%llu \n", current_buflen, (u_int64_t) (foundat_off - buf_off));
 #endif
 			if (signal_caught == SIGTERM || signal_caught == SIGINT)
 				{
@@ -443,6 +457,8 @@ int search_chunk(f_state *s, unsigned char *buf, f_info *i, u_int64_t chunk_size
 				current_pos = foundat;
 
 				/*Now lets analyze the file and see if we can determine its size*/
+
+				// printf("c_offset=%llu %x %x %llx\n", c_offset,foundat,buf,c_offset);
 				foundat = extract_file(s, c_offset, foundat, current_buflen, needle, f_offset);
 #ifdef DEBUG
 				if (foundat == NULL)
@@ -483,22 +499,22 @@ int search_chunk(f_state *s, unsigned char *buf, f_info *i, u_int64_t chunk_size
 #ifdef DEBUG
 						printf("	Bridge the gap\n");
 #endif
-
+						saveme = ftello(i->handle);
 						/*grow the buffer and try to extract again*/
 						newbuf = read_from_disk(c_offset + f_offset, i, needle->max_len);
 						if (newbuf == NULL)
 							break;
 						current_pos = extract_file(s,
 												   c_offset,
-												   current_pos,
-												   current_buflen,
+												   newbuf,
+												   needle->max_len,
 												   needle,
 												   f_offset);
 						if (!current_pos)
 							{
 
 							/*We failed so we should put the file* back*/
-							fseeko(i->handle, c_offset + f_offset, SEEK_SET);
+							fseeko(i->handle, saveme, SEEK_SET);
 							}
 
 						free(newbuf);
