@@ -84,12 +84,12 @@ unsigned char *extract_zip(f_state *s, u_int64_t c_offset, unsigned char *founda
 		if (foundat[2] == '\x03' && foundat[3] == '\x04')	//Verfiy we are looking at a local file header//
 			{
 			
-			localFH.compression=htos(&foundat[8], LITTLE_ENDIAN);
-			localFH.compressed = htoi(&foundat[18], LITTLE_ENDIAN);
-			localFH.uncompressed = htoi(&foundat[22], LITTLE_ENDIAN);
-			localFH.filename_length = htos(&foundat[26], LITTLE_ENDIAN);
-			localFH.extra_length = htos(&foundat[28], LITTLE_ENDIAN);;
-			localFH.genFlag = htos(&foundat[6], LITTLE_ENDIAN);	
+			localFH.compression=htos(&foundat[8], FOREMOST_LITTLE_ENDIAN);
+			localFH.compressed = htoi(&foundat[18], FOREMOST_LITTLE_ENDIAN);
+			localFH.uncompressed = htoi(&foundat[22], FOREMOST_LITTLE_ENDIAN);
+			localFH.filename_length = htos(&foundat[26], FOREMOST_LITTLE_ENDIAN);
+			localFH.extra_length = htos(&foundat[28], FOREMOST_LITTLE_ENDIAN);;
+			localFH.genFlag = htos(&foundat[6], FOREMOST_LITTLE_ENDIAN);	
 
 			// Sanity checking
 			if (localFH.compressed > needle->max_len)
@@ -217,7 +217,7 @@ unsigned char *extract_zip(f_state *s, u_int64_t c_offset, unsigned char *founda
 			return NULL;
 			}
 
-		comment_length = htos(foundat, LITTLE_ENDIAN);
+		comment_length = htos(foundat, FOREMOST_LITTLE_ENDIAN);
 		foundat += comment_length + 2;
 		file_size = (foundat - buf);
 #ifdef DEBUG
@@ -1113,10 +1113,10 @@ unsigned char *extract_wmv(f_state *s, u_int64_t c_offset, unsigned char *founda
 	unsigned char	*header = foundat;
 	unsigned char	*extractbuf = NULL;
 	unsigned char	*buf = foundat;
-	u_int64_t		size = 0;
+	unsigned int		size = 0;
 	u_int64_t		file_size = 0;
-	int				headerSize = 0;
-	int				fileObjHeaderSize = 0;
+	u_int64_t			headerSize = 0;
+	u_int64_t			fileObjHeaderSize = 0;
 	int				numberofHeaderObjects = 0;
 	int				reserved[2];
 	int				bytes_to_search = 0;
@@ -1127,18 +1127,22 @@ unsigned char *extract_wmv(f_state *s, u_int64_t c_offset, unsigned char *founda
 
 	foundat += 16;		/*Jump to the header size*/
 	headerSize = htoll(foundat, FOREMOST_LITTLE_ENDIAN);
+	//printx(foundat,0,8);
 	foundat += 8;
 	numberofHeaderObjects = htoi(foundat, FOREMOST_LITTLE_ENDIAN);
 	foundat += 4;		//Jump to the begin File properties obj
 	reserved[0] = foundat[0];
 	reserved[1] = foundat[1];
 	foundat += 2;
-
+	//printf("found WMV\n");
 	//end header obj
 	//****************************************************/
 	//Sanity Check
+	//printf("WMV num_header_objs=%d headerSize=%llu\n",numberofHeaderObjects,headerSize);
+
 	if (headerSize <= 0 || numberofHeaderObjects <= 0 || reserved[0] != 1)
 		{
+		printf("WMV err num_header_objs=%d headerSize=%llu\n",numberofHeaderObjects,headerSize);
 		return foundat;
 		}
 
@@ -1159,11 +1163,14 @@ unsigned char *extract_wmv(f_state *s, u_int64_t c_offset, unsigned char *founda
 	if (foundat)
 		{
 		foundat += 16;	/*jump to the headersize*/
-		fileObjHeaderSize = htoll(foundat, LITTLE_ENDIAN);
+		fileObjHeaderSize = htoll(foundat, FOREMOST_LITTLE_ENDIAN);
+		//printx(foundat,0,8);
 		foundat += 24;	//Jump to the file size obj
-		size = htoi(foundat, LITTLE_ENDIAN);
+		size = htoi(foundat, FOREMOST_LITTLE_ENDIAN);
+		//printx(foundat,0,8);
+		
 #ifdef DEBUG
-		printf("SIZE:=%lld\n", size);
+		printf("SIZE:=%u fileObjHeaderSize=%llu\n", size,fileObjHeaderSize);
 #endif
 		}
 	else
@@ -1291,7 +1298,7 @@ unsigned char *extract_bmp(f_state *s, u_int64_t c_offset, unsigned char *founda
 		return buf + needle->header_len;
 
 	/*JUMP the first to bytes of the header (BM)*/
-	size = htoi(&foundat[2], LITTLE_ENDIAN);	/*Grab the total file size in little_endian*/
+	size = htoi(&foundat[2], FOREMOST_LITTLE_ENDIAN);	/*Grab the total file size in little_endian*/
 
 	/*Sanity Check*/
 	if (size <= 100 || size > needle->max_len)
@@ -1336,7 +1343,8 @@ unsigned char *extract_bmp(f_state *s, u_int64_t c_offset, unsigned char *founda
 
 		file_size = size;
 		extractbuf = buf;
-		write_to_disk(s, needle, file_size, extractbuf, c_offset + f_offset);
+		
+		write_to_disk(s, needle, file_size, extractbuf, (c_offset + f_offset)-4);
 		foundat += file_size;
 		return foundat;
 
