@@ -78,6 +78,7 @@
 
 #elif defined (__MACOSX)
 #include <machine/endian.h>
+#define __U16_TYPE unsigned short
 #endif
 
 
@@ -89,7 +90,7 @@
 /* RBF - Do we need these type definitions? */ 
 #ifdef __SOLARIS
 #define   u_int32_t   unsigned int
-#define   u_int64_t   unsigned long
+#define   u_int64_t   unsigned long long
 #endif 
 
 
@@ -103,6 +104,7 @@
 
 #ifdef __UNIX
 
+#define __U16_TYPE unsigned short
 #include <libgen.h>
 
 #ifndef BYTE_ORDER 
