@@ -87,14 +87,24 @@ char *get_output_directory(f_state *s)
 int set_output_directory(f_state *s, char *fn)
 {
 	char	temp[PATH_MAX];
-
+  int 	fullpathlen=0;
 	/* We don't error check here as it's quite possible that the
      output directory doesn't exist yet. If it doesn't, realpath
      resolves the path correctly, but still returns NULL. */
+  //strncpy(s->output_directory,fn,PATH_MAX);
+  
 	realpath(fn, temp);
+	fullpathlen=strlen(temp);
 
-	/* RBF - Does this create a memory leak? What happens to the old value? */
-	s->output_directory = strdup(temp);
+	if(fullpathlen!=0)
+	{
+		s->output_directory = strdup(temp);
+	}
+	else
+	{
+		/*Realpath failed just use cwd*/
+		s->output_directory = strdup(fn);
+	}
 	return FALSE;
 }
 
@@ -259,7 +269,7 @@ void add_marker(f_state *s, int index, char *marker, int markerlength)
 void init_all(f_state *state)
 {
 	int index = 0;
-	init_builtin(state, JPEG, "jpg", "\xff\xd8\xff", "\xff\xd9", 3, 2, 2 * MEGABYTE, TRUE);
+	init_builtin(state, JPEG, "jpg", "\xff\xd8\xff", "\xff\xd9", 3, 2, 20 * MEGABYTE, TRUE);
 	index = init_builtin(state, GIF, "gif", "\x47\x49\x46\x38", "\x00\x3b", 4, 2, MEGABYTE, TRUE);
 	add_marker(state, index, "\x00\x00\x3b", 3);
 	init_builtin(state, BMP, "bmp", "BM", NULL, 2, 0, 2 * MEGABYTE, TRUE);
@@ -339,7 +349,7 @@ int set_search_def(f_state *s, char *ft, u_int64_t max_file_size)
 	if (strcmp(ft, "jpg") == 0 || strcmp(ft, "jpeg") == 0)
 		{
 		if (max_file_size == 0)
-			max_file_size = 2 * MEGABYTE;
+			max_file_size = 20 * MEGABYTE;
 		init_builtin(s, JPEG, "jpg", "\xff\xd8\xff", "\xff\xd9", 3, 2, max_file_size, TRUE);
 		}
 	else if (strcmp(ft, "gif") == 0)
